"""
SCED Matcher - A tool for matching K-12 course names and descriptions to standardized NCES SCED codes.
"""

from .matcher import SCEDMatcher

__version__ = "0.2.0"
__author__ = "Leoson Hoay"
__email__ = "leoson.public@gmail.com"

__all__ = ["SCEDMatcher"]